{ config, pkgs, ... }:

{
  home.packages = with pkgs; [
    fzy
    lf
    curl
    fd
    zsh-powerlevel10k
    zsh-autocomplete
    zsh-vi-mode
    ripgrep
    rsync
    moreutils
  ];
  home.sessionVariables = {
    BROWSER = "firefox";
    GPULAB_CERT = "${config.xdg.dataHome}/gpulab.pem";
    GPULAB_DEV = "False";
    GCC_COLORS = "error = '01;31:warning = '01;35:note = '01;36:caret = '01;32:locus = '01:quote = '01'";
    ARCHFLAGS = "-arch x86_64";
    TERM = "screen-256color";
    PYTHONDONTWRITEBYTECODE = "1";
    GOPATH = "${config.xdg.dataHome}/go";
  };
  home.file."${config.xdg.configHome}/zsh" = {
    source = ./files;
    recursive = true;
  };

  programs.command-not-found.enable = true;
  programs.zoxide = {
    enable = true;
    enableZshIntegration = true;
  };
  programs.fzf = {
    enable = true;
  };
  programs.zsh = {
    enable = true;
    enableCompletion = true;
    syntaxHighlighting.enable = false;
    autosuggestion.enable = true;

    initExtraFirst = ''
      source ${config.xdg.configHome}/zsh/p10k.zsh
      function zvm_after_init() {
          source ${config.xdg.configHome}/zsh/term.zsh
          source ${config.xdg.configHome}/zsh/completion.zsh
          source ${config.xdg.configHome}/zsh/waypipe.zsh
          if [ -n "\$\{commands[fzf-share]\}" ]; then
              source "$(fzf-share)/key-bindings.zsh"
              source "$(fzf-share)/completion.zsh"
          fi
          source ${config.xdg.configHome}/zsh/keys.zsh
      }
    '';

    shellAliases = {
      mallorea = "run_waypipe mallorea";
      vault = "run_waypipe vault";
      riva = "run_waypipe riva";
      kell = "run_waypipe kell";
      aloria = "run_waypipe aloria";

      ll = "ls -lhat";
      ls = "ls --color=auto";
      lf = "cd \"\$(${pkgs.lf}/bin/lf -print-last-dir)\"";

      compress = "tar --use-compress-program = lbzip2 -cvf";
      wget = "wget --hsts-file = \"$XDG_DATA_HOME/wget-hsts\"";
      python = "python3";
      v = "nvim -c ':lua require(\"oil\").open()' && cd \"\$(cat /tmp/oil_dir 2> /dev/null || pwd)\"";
      cpr = "rsync --archive -hh --partial --info = stats1,progress2 --modify-window = 1";
      mvr = "rsync --archive -hh --partial --info = stats1,progress2 --modify-window = 1 --remove-source-files";
      rg = "rg -i --colors 'match:bg:yellow' --colors 'match:fg:black' --colors 'match:style:nobold' --colors 'path:fg:green' --colors 'path:style:bold' --colors 'line:fg:yellow' --colors 'line:style:bold'";
      ag = "rg -i --colors 'match:bg:yellow' --colors 'match:fg:black' --colors 'match:style:nobold' --colors 'path:fg:green' --colors 'path:style:bold' --colors 'line:fg:yellow' --colors 'line:style:bold'";
      push = "git add -A && git commit -m \"`date`\" && git push";
      reset = "tput reset";
    };
    history.size = 10000000;
    history.save = 10000000;
    history.path = "${config.xdg.dataHome}/zsh/history";
    autocd = true;
    plugins = [
      {
        name = "zsh-powerlevel10k";
        src = "${pkgs.zsh-powerlevel10k}/share/zsh-powerlevel10k/";
        file = "powerlevel10k.zsh-theme";
      }
      {
        name = "vi-mode";
        src = pkgs.zsh-vi-mode;
        file = "share/zsh-vi-mode/zsh-vi-mode.plugin.zsh";
      }
    ];
  };
}
